@@ -16,7 +16,9 @@ class Review(object):
             raise ValueError('Invalid review page parameters')
 
         self._URL = URL
+        self._soup = None
 
+    @property
     @retry()
     def soup(self):
         if not self._soup:
@@ -90,6 +92,6 @@ class Review(object):
         d = {
             k:getattr(self, k)
             for k in dir(self)
-            if dict_acceptable(self, k)
+            if dict_acceptable(self, k, blacklist=['soup', '_URL', '_soup'])
         }
         return d
